@@ -148,12 +148,16 @@ class Plotter:
             plt.show()
         return
     
-    def plot_from_csv(self, csv_file, data=None,
+    def plot_from_csv(self, config, data=None,
                       theme='default', palette='viridis', aspect='big', 
                       save_folder=None, multi_process=False, **kwargs):
         """ Read CSV and plot all rows """
         # Read the configuration CSV file
-        config_df = pd.read_csv(csv_file).fillna('None').replace({'None': None})
+        if isinstance(config, str) and os.path.exists(config):
+            config_df = pd.read_csv(config).fillna(
+                'None').replace({'None': None})
+        else:
+            config_df = pd.DataFrame(config)
 
         # Prepare the list of jobs for multi-processing
         jobs = []
